# Docmost Cloudron Package

This package provides Docmost for Cloudron - an open-source collaborative wiki and documentation platform that serves as a modern alternative to Confluence and Notion.

## About Docmost

Docmost is a collaborative documentation platform featuring:
- Real-time collaborative editing
- Diagram support (Draw.io, Excalidraw, Mermaid)
- Page history and version control
- Permissions management
- Multilingual support (10+ languages)
- Rich text editing with modern UI

## Prerequisites

- Cloudron CLI installed (`npm install -g cloudron`)
- Access to a Cloudron instance
- Docker (for building)

## Building the Package

1. Clone this repository:
   ```bash
   git clone <repository-url>
   cd docmost-cloudron
   ```

2. Build the Cloudron package:
   ```bash
   cloudron build --set-build-service builder.docker.due.ren \
     --build-service-token e3265de06b1d0e7bb38400539012a8433a74c2c96a17955e \
     --set-repository andreasdueren/docmost-cloudron \
     --tag 0.1.2
   ```

## Installation

1. Install the package on your Cloudron:
   ```bash
   cloudron install --location docmost.yourdomain.com \
     --image andreasdueren/docmost-cloudron:0.1.2
   ```

2. After installation, access your Docmost instance at the configured domain.

3. Complete the initial setup by creating your first workspace and admin account.

## Configuration

### Environment Variables

The package automatically configures the following through Cloudron:

- **Database**: PostgreSQL (via `CLOUDRON_POSTGRESQL_URL`)
- **Redis**: Session and collaboration caching (via `CLOUDRON_REDIS_URL`)
- **Email**: SMTP configuration (via `CLOUDRON_MAIL_SMTP_*`)
- **Storage**: Local file storage in `/app/data/uploads`
- **Authentication**: OIDC integration with Cloudron users

### Custom Configuration

Additional configuration can be done through environment variables in the Cloudron app settings:

- `FILE_UPLOAD_SIZE_LIMIT`: Maximum file upload size (default: 50mb)
- `JWT_TOKEN_EXPIRES_IN`: JWT token expiration (default: 30d)

## Features

### Collaboration
- Real-time collaborative editing
- Comments and suggestions
- Page history and version control
- User permissions and workspace management

### Content Creation
- Rich text editor with markdown support
- Tables, lists, and formatting options
- Image and file uploads
- Math equations (LaTeX support)

### Diagrams
- Draw.io integration for flowcharts and diagrams
- Excalidraw for hand-drawn style diagrams
- Mermaid for text-based diagrams

### Organization
- Nested page structure
- Search functionality
- Tags and categorization
- Page templates

## Troubleshooting

### Build Issues

If the build fails, try:

1. **Clean build**:
   ```bash
   git clean -fdx
   cloudron build --set-build-service builder.docker.due.ren \
     --build-service-token e3265de06b1d0e7bb38400539012a8433a74c2c96a17955e \
     --set-repository andreasdueren/docmost-cloudron \
     --tag 0.1.3
   ```

2. **Check logs**:
   ```bash
   cloudron logs --app docmost.yourdomain.com -f
   ```

### Installation Issues

1. **Check app status**:
   ```bash
   cloudron status --app docmost.yourdomain.com
   ```

2. **Restart the app**:
   ```bash
   cloudron restart --app docmost.yourdomain.com
   ```

### Performance Issues

- Increase memory allocation in Cloudron app settings if needed (minimum 512MB recommended)
- Monitor disk usage for file uploads in `/app/data/uploads`

## Development

### Local Development

To modify the package:

1. Edit the relevant files (`Dockerfile`, `start.sh`, `nginx.conf`, etc.)
2. Commit changes to git
3. Rebuild and test:
   ```bash
   git add . && git commit -m "Update configuration"
   cloudron build --tag $(date +%s)
   ```

### Testing

Test the package locally:

1. Build with a test tag
2. Install on a test domain
3. Verify all features work correctly
4. Check logs for any errors

## Support

For issues related to:
- **Docmost application**: Visit [Docmost GitHub](https://github.com/docmost/docmost)
- **Cloudron packaging**: Create an issue in this repository
- **Cloudron platform**: Visit [Cloudron Documentation](https://docs.cloudron.io)

## License

This Cloudron package is provided under the same license as Docmost (AGPL-3.0).

## Version History

- **0.1.2**: Initial working version with OIDC authentication
- **0.1.1**: Build fixes for pnpm and dependencies
- **0.1.0**: Initial package structure

## Contributing

1. Fork this repository
2. Create a feature branch
3. Make your changes
4. Test thoroughly
5. Submit a pull request

Please ensure all changes are tested on a real Cloudron instance before submitting.